==> eiffelstudio-18.11.10.2592.tar: F_code/C11/bo516.c <==
/*
 * Code for class BOOLEAN_PREFERENCE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "bo516.h"
#include "eif_plug.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {BOOLEAN_PREFERENCE}.text_value */
EIF_REFERENCE F596_8203 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,tr1);
	RTLR(1,Result);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(2195, 0x00).id, 2195, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F2185_21342(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	tb1 = F593_8178(Current);
	{
		/* INLINED CODE (append_boolean) */
		tr1 = (tb1 ? makestr ("True", 4) : makestr ("False", 5));
		F2196_21777(RTCW(Result), tr1);
		/* END INLINED CODE */
	}
	;
	RTLE;
	return Result;
}

/* {BOOLEAN_PREFERENCE}.set_value */
void F596_8206 (EIF_REFERENCE Current, EIF_BOOLEAN arg1)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(F593_8178(Current) != arg1)) {
		F593_8175(Current, arg1);
	}
	RTLE;
}

/* {BOOLEAN_PREFERENCE}.set_value_from_string */
void F596_8208 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	tr1 = RTMS_EX_H("true",4,1953658213);
	tb1 = F2185_21384(RTCW(arg1), tr1);
	{
		/* INLINED CODE (set_value) */
		tb2 = F593_8178(Current);
		if ((EIF_BOOLEAN)(tb2 != tb1)) {
			F593_8175(Current, tb1);
		}
		/* END INLINED CODE */
	}
	;
	RTLE;
}

void EIF_Minit516 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C11/bo516.c <==
/*
 * Code for class BOOLEAN_PREFERENCE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "bo516.h"
#include "eif_plug.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {BOOLEAN_PREFERENCE}.text_value */
EIF_REFERENCE F600_8158 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Result);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	Result = RTLNS(eif_new_type(2221, 0x00).id, 2221, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F2213_21539(RTCW(Result));
	tb1 = F596_8133(Current);
	{
		/* INLINED CODE (STRING_32.append_boolean) */
		tr1 = (tb1 ? makestr ("True", 4) : makestr ("False", 5));
		F2222_21944(RTCW(Result), tr1);
		/* END INLINED CODE */
	}
	;
	RTLE;
	return Result;
}

/* {BOOLEAN_PREFERENCE}.set_value */
void F600_8161 (EIF_REFERENCE Current, EIF_BOOLEAN arg1)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(F596_8133(Current) != arg1)) {
		F596_8130(Current, arg1);
	}
	RTLE;
}

/* {BOOLEAN_PREFERENCE}.set_value_from_string */
void F600_8163 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTGC;
	tr1 = RTMS_EX_H("true",4,1953658213);
	tb1 = F2213_21581(RTCW(arg1), tr1);
	{
		/* INLINED CODE (BOOLEAN_PREFERENCE.set_value) */
		tb2 = F596_8133(Current);
		if ((EIF_BOOLEAN)(tb2 != tb1)) {
			F596_8130(Current, tb1);
		}
		/* END INLINED CODE */
	}
	;
	RTLE;
}

void EIF_Minit516 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
